@@ -1,28 +1,51 @@
 #coding:UTF-8
 #Author : AC97
+#Maintain : AC96,AC97
 #Project name : civilianM
 #Class : MAIN
 #Contact EMail: ehcemc@hotmail.com
 #NO COPYING!
-import time
+import time as te
 import platform
 import os
 import sys
 import string
-import random
+import random as rm
 import os.path
 import winreg
 import socket
-import requests
+import webbrowser
+import requests as rs
 import json
 import getpass
 from bs4 import BeautifulSoup as bs
 from datetime import datetime as dt
-v='2.4.97'
+v='2.5.97'
+n='civilianM'
+a='AC97'
+m='AC96'
 __all__ = ('upgrade','checkClass','wait','randint','decimal','garbledCode','pausePrint','captcha','judge',
-    'hideInput','justNow','openFolder','getAddress','find','author','safe','error','myos','NumberError',
-    'LibraryError','ConscienceError','NetworkError','ArgeementWarning')
+    'hideInput','justNow','openFolder','getAddress','find','author','safe','error','myos',
+    'LibraryError','ConscienceError','ArgeementWarning','openWeb','UnknownError','whatNews')
 #print("欢迎使用civilianM，当前版本："+v)
+def whatNews():
+    whatNew = ['2021-10-16 civilianM-2.5.97 更新日志',
+        '1.cMES(civilianM Encry Standard |civilianM加密标准)更新至1.0代',
+        '2.openFolder()参数 fn可以忽略',
+        '3:增加openWeb()功能',
+        '4. find()使用search()以后需要find().show获取结果',
+        '5.error()类新增加5种错误，并且忽略cont参数时，只会返回 " "',
+        '6. cert.py/do()全部改中文',
+        '7.civilianM增加一位维护员：AC96',
+        '8. login.py缓存文件future.whl更名dontlook.fkyu',
+        '9.删除了PyOpenSSL依赖库',
+        '10.author()增加新函数：manage()',
+        '11.访问author()的函数时无需加括号。（a=author;a.manage）',
+        '12.author() old()不返回LibraryError']
+    for n in whatNew:
+        if n == whatNew[0]:
+            print(n)
+        print('\t'+n)
 
 def upgrade():
     """功能：检查更新
@@ -31,11 +54,9 @@ def upgrade():
     
     global v
     dd = []
-    try:
-        r = requests.get('https://pypi.org/project/civilianM/#history')
-    except:
-        raise NetworkError(
-            '请检查网络连接状态')
+    r = (
+            rs
+            .get('https://pypi.org/project/civilianM/#history'))
     s = bs(r.text,'lxml')
     d = s.find_all('p',class_='release__version')
     for nn in d:
@@ -45,15 +66,19 @@ def upgrade():
     cur = v.split('.')
     #Not same
     if int(new[0]) == int(cur[0]) and int(new[1]) > int(cur[1]):
-    	print("你正在使用的是  "+v+",截至目前  "+dd[0]+"已经发布，请及时更新")
+    	print("你正在使用的是   "+v+",截至目前  "+dd[0]+" 已经发布，请及时更新")
     #same
     elif int(new[0]) == int(cur[0]) and int(new[1]) == int(cur[1]):
-    	print("你正在使用最新版本  "+v+" 暂时不需要更新")
+    	print("你正在使用最新版本  "+v+"  暂时不需要更新")
     elif int(new[0]) == int(cur[0]) and int(cur[1]) > int(new[1]):
     	#teast
-    	print("你正在使用测试版本 "+v+",在PyPi上civilianM的最新版本是 "+dd[0])
+    	print("你正在使用测试版本   "+v+",在PyPi上civilianM的最新版本是 "+dd[0])
 
 def checkClass(objects,need):
+    attribute = ['str','list','dict','int','float','tuple']
+    if need not in attribute:
+        raise AttributeError(
+            "无效参数："+need)
     """功能：检查是否为指定类型
     objects:检查对象
     need:指定类型（str/list/dist/int/float/tuple）（必须是字符串）
@@ -79,14 +104,10 @@ def checkClass(objects,need):
 def wait(t):
     """功能：让程序睡眠
     实际上就是time的sleep
-    t : 时间，单位：秒
-    """
-    
-    if checkClass(t,'float') or checkClass(t,'int'):
-        time.sleep(t)
-    else:
-        raise NumberError(
-            """必须输入一个小数/整数""")
+    t : 时间，单位：秒"""
+    return (
+        te
+            .sleep(t))
 
 #Randomly generated number
 def randint(mins,maxs):
@@ -95,61 +116,36 @@ def randint(mins,maxs):
     mins:最小数
     maxs:最大数
     """
-    
-    if checkClass(mins,'int') == False or checkClass(maxs,'int') == False:
-        raise NumberError(
-            """必须输入整数""")
-    if maxs == mins:
-        raise NumberError(
-            """最大数不得等于最小数""")
-    elif mins > maxs:
-        raise NumberError(
-            """最小数不得大于最大数""")
-    return random.randint(mins,maxs)
+    return (
+        rm
+            .randint(mins,maxs))
 
 def decimal(mins,maxs,save=None):
-    if checkClass(mins,'float') == False or checkClass(maxs,'float') == False:
-        raise NumberError(
-            """ 必须输入浮点数""")
-        raise NumberError(
-            """最大数不得等于最小数""")
-    elif mins > maxs:
-        raise NumberError(
-            """最小数不得大于最大数""")
     if save == None:
-        return random.uniform(mins,maxs)
+        return (
+            rm
+            .uniform(mins,maxs))
     elif save != None:
-        if checkClass(save,'int'):
-            return round(random.uniform(mins,maxs),save)
-        else:
-            raise NumberError(
-                "指定save参数时，该参数传入的值必须是整数")
+        return (
+            round(
+            rm
+            .uniform(mins,maxs)),save)
+    else:
+        raise UnknownError(
+            "未知错误")
 
-def garbledCode(digit=20,types=None):
+def garbledCode(digit=20):
     """功能：常见的一堆乱码
     digit:位数，（digit > 0）
     types:类型，只有None和Upper
     """
     result = ""
-    if types == None or types == 'Upper':
-        pass
-    else:
-        raise AttributeError(
-            '无效参数：'+str(types))
     np= ""
     standard = [1,2,3,4,5,6,7,8,9,0,'a','b','c','d','e','f']
-    if checkClass(digit,'int')==False:
-        raise NumberError(
-            """必须输入整数""")
-    for n in range(digit):
+    for n in range(
+        digit):
         np = standard[randint(0,15)]
-        if types == 'Upper':
-            if checkClass(np,'str'):
-                result += np.upper()
-            else:
-                result += str(np)
-        else:
-            result += str(np)
+        result += str(np)
     return result
 
 def pausePrint(*content,pause=0.2):
@@ -157,16 +153,14 @@ def pausePrint(*content,pause=0.2):
     content:打印的内容
     pause:停顿时间
     """
-    if checkClass(pause,'float') or checkClass(pause,'int'):
-        for tex in content:
-            for prin in tex:
-                print(prin,end='',flush=True)
-                wait(pause)
-            print(" ",flush=True,end="")
-        print("\n",flush=True,end="")
-    else:
-        raise NumberError(
-            """必须输入小数/浮点数""")
+    for tex in content:
+        for prin in str(tex):
+            print(prin,end='',flush=True)
+            (
+                wait
+                (pause))
+        print(" ",flush=True,end="")
+    print("\n",flush=True,end="")
     
 def captcha():
     """功能：生成一个CAPTCHA验证码
@@ -176,10 +170,14 @@ def captcha():
     N = [1,2,3,4,5,6,7,8,9,0,'a','A','b','B','c','C','d','D','e','E','f','F','g','G','h','H','i','I','j','J','k','K','l','L','m','M',
          'n','N','o','O','p','P','q','Q','r','R','s','S','t','T','u','U','v','V','w','W','x','X','y','Y','z','Z']
     for n in range(4):
-        capt += str(N[randint(0,57)])
+        capt += str(N[randint(0,61)])
     return capt
 
 def judge(content,classes):
+    attribute = ['yn','tf','oc']
+    if classes not in attribute:
+        raise AttributeError(
+            "无效参数："+classes)
     """功能：判断
     ontent:内容
     classes:判断类型（yn/tf/oc）
@@ -223,10 +221,12 @@ def justNow():
     b = dt.today()
     return b.strftime("%Y-%m-%d %H:%M:%S")
 
-def openFolder(fn):
+def openFolder(fn=None):
     def efve():
         key = winreg.OpenKey(winreg.HKEY_CURRENT_USER, r'Software\Microsoft\Windows\CurrentVersion\Explorer\Shell Folders')
         return winreg.QueryValueEx(key, "Desktop")[0] + "/"
+    if fn==None:
+        nh = efve() + 'example'
     if fn:
         nh = efve() + fn
     if not os.path.exists(nh):
@@ -240,11 +240,9 @@ def openFolder(fn):
     #return nh + "/"
 
 def getAddress():
-    try:
-        re = requests.get('https://ipw.cn/api/ip/locate')
-    except:
-        raise NetworkError(
-            "请检查网络连接状态")
+    re = (
+        rs
+              .get('https://ipw.cn/api/ip/locate'))
     d = json.loads(re.text)
     PR = d['Address']['Province']
     ISP = "中国"+d['ISP']
@@ -266,6 +264,9 @@ def getAddress():
           'computer':{'name':comp,'computerIP':comip}}
     return nr
 
+def openWeb(website):
+    webbrowser.open(website)
+
 gr = []
 ttt = 0
 ia = None
@@ -302,9 +303,10 @@ class find():
         for disk in cd:
             for root,dirs,files in os.walk(disk,True):
                 fb.sds(root,n,dirs)
-                ttt += 0.1
+                ttt += 1
                 fb.sfs(root,n,dirs)
         ia = n
+    @property
     def show(self):
         global gr
         global ia
@@ -330,79 +332,112 @@ class error():
         pass
     def attribute(self,cont=None):
         if cont==None:
-            raise AttributeError('The passed in function cannot be left blank and equal to None')
+            raise AttributeError(' ')
         elif cont != None:
             raise AttributeError(cont)
     def syntax(self,cont=None):
         if cont==None:
-            raise SyntaxError('The passed in function cannot be left blank and equal to None')
+            raise SyntaxError(' ')
         elif cont != None:
             raise SyntaxError(cont)
     def value(self,cont=None):
         if cont ==None:
-            raise ValueError('The passed in function cannot be left blank and equal to None')
+            raise ValueError(' ')
         elif cont != None:
             raise ValueError(cont)
     def exception(self,cont=None):
         if cont==None:
-            raise Exception('The passed in function cannot be left blank and equal to None')
+            raise Exception(' ')
         elif cont != None:
             raise Exception(cont)
     def name(self,cont=None):
         if cont==None:
-            raise NameError('The passed in function cannot be left blank and equal to None')
+            raise NameError(' ')
         elif cont != None:
             raise NameError(cont)
     def io(self,cont=None):
         if cont==None:
-            raise IOError('The passed in function cannot be left blank and equal to None')
+            raise IOError(' ')
         elif cont != None:
             raise IOError(cont)
     def Type(self,cont=None):
         if cont==None:
-            raise TypeError('The passed in function cannot be left blank and equal to None')
+            raise TypeError(' ')
         elif cont != None:
             raise TypeError(cont)
     def indentation(self,cont=None):
         if cont==None:
-            raise IndentationError('The passed in function cannot be left blank and equal to None')
+            raise IndentationError(' ')
         elif cont != None:
             raise IndentationError(cont)
     def index(self,cont=None):
         if cont==None:
-            raise IndexError('The passed in function cannot be left blank and equal to None')
+            raise IndexError(' ')
         elif cont != None:
             raise IndexError(cont)
     def Import(self,cont=None):
         if cont == None:
-            raise ImportError('The passed in function cannot be left blank and equal to None')
+            raise ImportError(' ')
         elif cont!=None:
             raise ImportError(cont)
     def key(self,cont=None):
         if cont == None:
-            raise KeyError('The passed in function cannot be left blank and equal to None')
+            raise KeyError(' ')
         elif cont!=None:
             raise KeyError(cont)
     def unicode(self,cont=None):
         if cont == None:
-            raise UnicodeDecodeError('The passed in function cannot be left blank and equal to None')
+            raise UnicodeDecodeError(' ')
         elif cont!=None:
             raise UnicodeDecodeError(cont)
     def zero(self,cont=None):
         if cont == None:
-            raise ZeroDivisionError('The passed in function cannot be left blank and equal to None')
+            raise ZeroDivisionError(' ')
         elif cont!=None:
             raise ZeroDivisionError(cont)
     def eof(self,cont=None):
         if cont == None:
-            raise EOFError('The passed in function cannot be left blank and equal to None')
+            raise EOFError(' ')
         elif cont!=None:
             raise EOFError(cont)
-    #'The passed in function cannot be left blank and equal to None'
+    def windows(self,cont=None):
+        if cont == None:
+            raise WindowsError(' ')
+        elif cont!=None:
+            raise WindowsError(cont)
+    def runtime(self,cont=None):
+        if cont == None:
+            raise RuntimeError(' ')
+        elif cont!=None:
+            raise RuntimeError(cont)
+    def timeout(self,cont=None):
+        if cont == None:
+            raise TimeoutError(' ')
+        elif cont!=None:
+            raise TimeoutError(cont)
+    def lookup(self,cont=None):
+        if cont == None:
+            raise LookupError(' ')
+        elif cont!=None:
+            raise LookupError(cont)
+    def filenotfound(self,cont=None):
+        if cont == None:
+            raise FileNotFoundError(' ')
+        elif cont!=None:
+            raise FileNotFoundError(cont)
 
+Ddbyu8s8dgB = '161368616001626129613651687'
 class safe():
-    def encry(self,string):
-        standard = {
+    def cMES10(token,status):
+        #civilianM Encry Standard 1.0
+        d = token.split("6")
+        if len(d) >= 11 or len(d) <= 9:
+            print(d)
+            raise LibraryError(
+                "Token error")
+        else:
+            if status:
+                Encr = {
         '1':'?',
         '2':':',
         '3':'@',
@@ -419,22 +454,29 @@ class safe():
         'd':'_',
         'e':'>',
         'f':',',
-        'g':'/'
-        }
-        d = ""
-        for n in str(string):
-            try:
-                n = standard[n]
-            except KeyError:
-                n = n.lower()
-                try:
-                    n = standard[n]
-                except KeyError:
-                    pass
-            d += n
-        print(d)
-    def decode(self,string):
-        standard = {
+        'g':'/',
+        'h':'<',
+        'i':'{',
+        'j':'"',
+        'k':"'",
+        'l':'-',
+        'm':'%',
+        'n':'&',
+        'o':'|',
+        'p':'~',
+        'q':'`',
+        'r':')',
+        's':'(',
+        't':']',
+        'u':'}',
+        'v':'1',
+        'w':'3',
+        'x':'5',
+        'y':'7',
+        'z':'9'}
+                return Encr
+            elif status == False:
+                Deco = {
         '?':'1',
         ':':'2',
         '@':'3',
@@ -451,8 +493,49 @@ class safe():
         '_':'d',
         '>':'e',
         ',':'f',
-        '/':'g'
-        }
+        '/':'g',
+        '<':'h',
+        '{':'i',
+        '"':'j',
+        "'":'k',
+        '-':'l',
+        '%':'m',
+        '&':'n',
+        '|':'o',
+        '~':'p',
+        '`':'q',
+        ')':'r',
+        '(':'s',
+        ']':'t',
+        '}':'u',
+        '1':'v',
+        '3':'w',
+        '5':'x',
+        '7':'y',
+        '9':'z'}
+                return Deco
+            else:
+                raise UnknownError("UnknownError")
+    def encry(self,string):
+        d = ""
+        standard = (
+            safe
+            .cMES10(Ddbyu8s8dgB,True))
+        for n in str(string):
+            try:
+                n = standard[n]
+            except KeyError:
+                n = n.lower()
+                try:
+                    n = standard[n]
+                except KeyError:
+                    pass
+            d += n
+        return d
+    def decode(self,string):
+        standard = (
+            safe
+            .cMES10(Ddbyu8s8dgB,False))
         d = ""
         for n in str(string):
             try:
@@ -464,37 +547,35 @@ class safe():
                 except KeyError:
                     pass
             d += n
-        print(d)
+        return d
+
 class author():
     def __init__(self):
         pass
+    @property
     def name(self):
         print('AC97')
+    @property
     def email(self):
-        print("ehcemc@163.com")
+        print("ehcemc@hotmail.com")
+    @property
     def old(self):
-        raise LibraryError(
-            "读取器无法从cmLib-OO读取这个部分：'MyOld'")
+        print('12.1 -- 30.6 Years old')
+    @property
     def gender(self):
         print('male')
+    @property
     def phoneNumber(self):
         print('+8613417083101')
+    @property
     def From(self):
         print("CN")
+    @property
     def live(self):
         print("中国,广西壮族自治区")
-
-class NumberError(Exception):
-    def __init__(self,error):
-        self.error=error
-    def __str__(self,*args):
-        return self.error
-
-class NetworkError(Exception):
-    def __init__(self,error):
-        self.error=error
-    def __str__(self,*args):
-        return self.error
+    @property
+    def manage(self):
+        print("AC97，AC96")
 
 class ArgeementWarning(Exception):
     def __init__(self,error):
@@ -513,5 +594,8 @@ class LibraryError(Exception):
         self.error=error
     def __str__(self,*args):
         return self.error
-
-
+class UnknownError(WindowsError):
+    def __init__(self,error):
+        self.error=error
+    def __str__(self,*args):
+        return self.error
